/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.settings.bluetooth;


import android.content.Context;
import android.support.v14.preference.PreferenceFragment;
import android.support.v7.preference.PreferenceScreen;
import android.util.Pair;

import com.android.settings.applications.LayoutPreference;
import com.android.settings.widget.EntityHeaderController;
import com.android.settingslib.bluetooth.CachedBluetoothDevice;
import com.android.settingslib.core.lifecycle.Lifecycle;

/**
 * This class adds a header with device name and status (connected/disconnected, etc.).
 */
public class BluetoothDetailsHeaderController extends BluetoothDetailsController {

    private EntityHeaderController mHeaderController;

    public BluetoothDetailsHeaderController(Context context, PreferenceFragment fragment,
            CachedBluetoothDevice device, Lifecycle lifecycle) {
        super(context, fragment, device, lifecycle);
    }

    @Override
    protected void init(PreferenceScreen screen) {
        mHeaderController = EntityHeaderController.newInstance(mFragment.getActivity(), mFragment,
                null);
        LayoutPreference pref = mHeaderController.done(mFragment.getActivity(), mContext);
        screen.addPreference(pref);
    }

    protected void setHeaderProperties() {
        Pair<Integer, String> pair = Utils.getBtClassDrawableWithDescription
                (mContext.getResources(), mCachedDevice);
        int summaryResourceId = mCachedDevice.getConnectionSummary();
        mHeaderController.setLabel(mCachedDevice.getName());
        mHeaderController.setIcon(mContext.getDrawable(pair.first));
        mHeaderController.setIconContentDescription(pair.second);
        mHeaderController.setSummary(
                summaryResourceId > 0 ? mContext.getString(summaryResourceId) : null);
    }

    @Override
    protected void refresh() {
        setHeaderProperties();
        mHeaderController.done(mFragment.getActivity(), false);
    }

    @Override
    public String getPreferenceKey() {
        return EntityHeaderController.PREF_KEY_APP_HEADER;
    }
}
